==> haskell-newtype-generics-0.6.2-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 newtype-generics
version:              0.6.2
visibility:           public
id:                   newtype-generics-0.6.2-GluMhXLdy1I3zUmd9rWBlO
key:                  newtype-generics-0.6.2-GluMhXLdy1I3zUmd9rWBlO
license:              BSD-3-Clause
maintainer:           Simon Jakobi <simon.jakobi@gmail.com>
author:
    Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi

homepage:             http://github.com/sjakobi/newtype-generics
synopsis:             A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.

category:             Control
abi:                  16267de1873ddb016fa4fe7886e8533a
exposed:              True
exposed-modules:      Control.Newtype.Generics
import-dirs:          /usr/lib/ghc-9.4.8/site-local/newtype-generics-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/newtype-generics-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/newtype-generics-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-newtype-generics
hs-libraries:         HSnewtype-generics-0.6.2-GluMhXLdy1I3zUmd9rWBlO
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock

haddock-html:         /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-newtype-generics-0.6.2-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-newtype-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 newtype-generics
version:              0.6.2
visibility:           public
id:                   newtype-generics-0.6.2-xByXzTf3hG2sDTxupYK2W
key:                  newtype-generics-0.6.2-xByXzTf3hG2sDTxupYK2W
license:              BSD-3-Clause
maintainer:           Simon Jakobi <simon.jakobi@gmail.com>
author:
    Darius Jahandarie, Conor McBride, João Cristóvão, Simon Jakobi

homepage:             http://github.com/sjakobi/newtype-generics
synopsis:             A typeclass and set of functions for working with newtypes
description:
    Per Conor McBride, the Newtype typeclass represents the packing and unpacking of a newtype,
    and allows you to operate under that newtype with functions such as ala.
    Generics support was added in version 0.4, making this package a full replacement
    for the original newtype package, and a better alternative to newtype-th.

category:             Control
abi:                  1e39fc78d58339d5d1e0bb8ef5d819b7
exposed:              True
exposed-modules:      Control.Newtype.Generics
import-dirs:          /usr/lib/ghc-9.4.8/site-local/newtype-generics-0.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/newtype-generics-0.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/newtype-generics-0.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-newtype-generics
hs-libraries:         HSnewtype-generics-0.6.2-xByXzTf3hG2sDTxupYK2W
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-newtype-generics/html/newtype-generics.haddock

haddock-html:         /usr/share/doc/haskell-newtype-generics/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
